Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Forecast.

Actions, resources, and condition keys for Amazon Forecast - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Forecast

Amazon Forecast (service prefix: `forecast` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Forecast
- Resource types defined by Amazon Forecast
- Condition keys for Amazon Forecast

## Actions defined by Amazon Forecast

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateAutoPredictor | Grants permission to create an auto predictor | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateDataset | Grants permission to create a dataset | Write | dataset* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDatasetGroup | Grants permission to create a dataset group | Write | datasetGroup* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDatasetImportJob | Grants permission to create a dataset import job | Write | datasetImportJob* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateExplainability | Grants permission to create an explainability | Write | forecast* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateExplainabilityExport | Grants permission to create an explainability export using an explainability resource | Write | explainability* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateForecast | Grants permission to create a forecast | Write | predictor* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateForecastExportJob | Grants permission to create a forecast export job using a forecast resource | Write | forecast* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreatePredictor | Grants permission to create a predictor | Write | datasetGroup* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreatePredictorBacktestExportJob | Grants permission to create a predictor backtest export job using a predictor | Write | predictor* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteDataset | Grants permission to delete a dataset | Write | dataset* |  |
DeleteDatasetGroup | Grants permission to delete a dataset group | Write | datasetGroup* |  |
DeleteDatasetImportJob | Grants permission to delete a dataset import job | Write | datasetImportJob* |  |
DeleteExplainability | Grants permission to delete an explainability | Write | explainability* |  |
DeleteExplainabilityExport | Grants permission to delete an explainability export | Write | explainabilityExport* |  |
DeleteForecast | Grants permission to delete a forecast | Write | forecast* |  |
DeleteForecastExportJob | Grants permission to delete a forecast export job | Write | forecastExport* |  |
DeletePredictor | Grants permission to delete a predictor | Write | predictor* |  |
DeletePredictorBacktestExportJob | Grants permission to delete a predictor backtest export job | Write | predictorBacktestExportJob* |  |
DeleteResourceTree | Grants permission to delete a resource and its child resources | Write | dataset* |  |
datasetGroup* |  |
datasetImportJob* |  |
explainability* |  |
explainabilityExport* |  |
forecast* |  |
forecastExport* |  |
predictor* |  |
predictorBacktestExportJob* |  |
DescribeAutoPredictor | Grants permission to describe an auto predictor | Read | predictor* |  |
DescribeDataset | Grants permission to describe a dataset | Read | dataset* |  |
DescribeDatasetGroup | Grants permission to describe a dataset group | Read | datasetGroup* |  |
DescribeDatasetImportJob | Grants permission to describe a dataset import job | Read | datasetImportJob* |  |
DescribeExplainability | Grants permission to describe an explainability | Read | explainability* |  |
DescribeExplainabilityExport | Grants permission to describe an explainability export | Read | explainabilityExport* |  |
DescribeForecast | Grants permission to describe a forecast | Read | forecast* |  |
DescribeForecastExportJob | Grants permission to describe a forecast export job | Read | forecastExport* |  |
DescribePredictor | Grants permission to describe a predictor | Read | predictor* |  |
DescribePredictorBacktestExportJob | Grants permission to describe a predictor backtest export job | Read | predictorBacktestExportJob* |  |
GetAccuracyMetrics | Grants permission to get the Accuracy Metrics for a predictor | Read | predictor* |  |
ListDatasetGroups | Grants permission to list all the dataset groups | Read |  |  |
ListDatasetImportJobs | Grants permission to list all the dataset import jobs | Read |  |  |
ListDatasets | Grants permission to list all the datasets | Read |  |  |
ListExplainabilities | Grants permission to list all the explainabilities | Read |  |  |
ListExplainabilityExports | Grants permission to list all the explainability exports | Read |  |  |
ListForecastExportJobs | Grants permission to list all the forecast export jobs | Read |  |  |
ListForecasts | Grants permission to list all the forecasts | Read |  |  |
ListPredictorBacktestExportJobs | Grants permission to list all the predictor backtest export jobs | Read |  |  |
ListPredictors | Grants permission to list all the predictors | Read |  |  |
ListTagsForResource | Grants permission to list the tags for an Amazon Forecast resource | Read | dataset |  |
datasetGroup |  |
datasetImportJob |  |
explainability |  |
explainabilityExport |  |
forecast |  |
forecastExport |  |
predictor |  |
predictorBacktestExportJob |  |
QueryForecast | Grants permission to retrieve a forecast for a single item | Read | forecast* |  |
StopResource | Grants permission to stop Amazon Forecast resource jobs | Write | datasetImportJob* |  |
explainability* |  |
explainabilityExport* |  |
forecast* |  |
forecastExport* |  |
predictor* |  |
predictorBacktestExportJob* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
TagResource | Grants permission to associate the specified tags to a resource | Tagging | dataset |  |
datasetGroup |  |
datasetImportJob |  |
explainability |  |
explainabilityExport |  |
forecast |  |
forecastExport |  |
predictor |  |
predictorBacktestExportJob |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to delete the specified tags for a resource | Tagging | dataset |  |
datasetGroup |  |
datasetImportJob |  |
explainability |  |
explainabilityExport |  |
forecast |  |
forecastExport |  |
predictor |  |
predictorBacktestExportJob |  |
| aws:TagKeys |
UpdateDatasetGroup | Grants permission to update a dataset group | Write | dataset* |  |
datasetGroup* |  |

## Resource types defined by Amazon Forecast

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
dataset | `arn:$ { Partition}:forecast:$ { Region}:$ { Account}:dataset/$ { ResourceId}` | aws:ResourceTag/${TagKey}
datasetGroup | `arn:$ { Partition}:forecast:$ { Region}:$ { Account}:dataset-group/$ { ResourceId}` | aws:ResourceTag/${TagKey}
datasetImportJob | `arn:$ { Partition}:forecast:$ { Region}:$ { Account}:dataset-import-job/$ { ResourceId}` | aws:ResourceTag/${TagKey}
algorithm | `arn:$ { Partition}:forecast:::algorithm/$ { ResourceId}` |
predictor | `arn:$ { Partition}:forecast:$ { Region}:$ { Account}:predictor/$ { ResourceId}` | aws:ResourceTag/${TagKey}
predictorBacktestExportJob | `arn:$ { Partition}:forecast:$ { Region}:$ { Account}:predictor-backtest-export-job/$ { ResourceId}` | aws:ResourceTag/${TagKey}
forecast | `arn:$ { Partition}:forecast:$ { Region}:$ { Account}:forecast/$ { ResourceId}` | aws:ResourceTag/${TagKey}
forecastExport | `arn:$ { Partition}:forecast:$ { Region}:$ { Account}:forecast-export-job/$ { ResourceId}` | aws:ResourceTag/${TagKey}
explainability | `arn:$ { Partition}:forecast:$ { Region}:$ { Account}:explainability/$ { ResourceId}` | aws:ResourceTag/${TagKey}
explainabilityExport | `arn:$ { Partition}:forecast:$ { Region}:$ { Account}:explainability-export/$ { ResourceId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Forecast

Amazon Forecast defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.